@@ -187,7 +187,16 @@ static JSValueConst python_to_quickjs(ContextData *context, PyObject *item) {
 	if (PyBool_Check(item)) {
 		return JS_MKVAL(JS_TAG_BOOL, item == Py_True ? 1 : 0);
 	} else if (PyLong_Check(item)) {
-		return JS_MKVAL(JS_TAG_INT, PyLong_AsLong(item));
+		int overflow;
+		long value = PyLong_AsLongAndOverflow(item, &overflow);
+		if (overflow) {
+			PyObject *float_value = PyNumber_Float(item);
+			double double_value = PyFloat_AsDouble(float_value);
+			Py_DECREF(float_value);
+			return JS_NewFloat64(context->context, double_value);
+		} else {
+			return JS_MKVAL(JS_TAG_INT, value);
+		}
 	} else if (PyFloat_Check(item)) {
 		return JS_NewFloat64(context->context, PyFloat_AsDouble(item));
 	} else if (item == Py_None) {
@@ -237,6 +246,37 @@ static PyObject *object_call(ObjectData *self, PyObject *args, PyObject *kwds) {
 	return quickjs_to_python(self->context, value);
 }
 
+// Converts the current Javascript exception to a Python exception via a C string.
+static void quickjs_exception_to_python(JSContext *context) {
+	JSValue exception = JS_GetException(context);
+	const char *cstring = JS_ToCString(context, exception);
+	const char *stack_cstring = NULL;
+	if (!JS_IsNull(exception) && !JS_IsUndefined(exception)) {
+		JSValue stack = JS_GetPropertyStr(context, exception, "stack");
+		if (!JS_IsException(stack)) {
+			stack_cstring = JS_ToCString(context, stack);
+			JS_FreeValue(context, stack);
+		}
+	}
+	if (cstring != NULL) {
+		const char *safe_stack_cstring = stack_cstring ? stack_cstring : "";
+		if (strstr(cstring, "stack overflow") != NULL) {
+			PyErr_Format(StackOverflow, "%s\n%s", cstring, safe_stack_cstring);
+		} else {
+			PyErr_Format(JSException, "%s\n%s", cstring, safe_stack_cstring);
+		}
+	} else {
+		// This has been observed to happen when different threads have used the same QuickJS
+		// runtime, but not at the same time.
+		// Could potentially be another problem though, since JS_ToCString may return NULL.
+		PyErr_Format(JSException,
+					 "(Failed obtaining QuickJS error string. Concurrency issue?)");
+	}
+	JS_FreeCString(context, cstring);
+	JS_FreeCString(context, stack_cstring);
+	JS_FreeValue(context, exception);
+}
+
 // Converts a JSValue to a Python object.
 //
 // Takes ownership of the JSValue and will deallocate it (refcount reduced by 1).
@@ -248,6 +288,10 @@ static PyObject *quickjs_to_python(ContextData *context_obj, JSValue value) {
 
 	if (tag == JS_TAG_INT) {
 		return_value = Py_BuildValue("i", JS_VALUE_GET_INT(value));
+	} else if (tag == JS_TAG_BIG_INT) {
+		const char *cstring = JS_ToCString(context, value);
+		return_value = PyLong_FromString(cstring, NULL, 10);
+		JS_FreeCString(context, cstring);
 	} else if (tag == JS_TAG_BOOL) {
 		return_value = Py_BuildValue("O", JS_VALUE_GET_BOOL(value) ? Py_True : Py_False);
 	} else if (tag == JS_TAG_NULL) {
@@ -255,41 +299,14 @@ static PyObject *quickjs_to_python(ContextData *context_obj, JSValue value) {
 	} else if (tag == JS_TAG_UNDEFINED) {
 		return_value = Py_None;
 	} else if (tag == JS_TAG_EXCEPTION) {
-		// We have a Javascript exception. We convert it to a Python exception via a C string.
-		JSValue exception = JS_GetException(context);
-		const char *cstring = JS_ToCString(context, exception);
-		const char *stack_cstring = NULL;
-		if (!JS_IsNull(exception) && !JS_IsUndefined(exception)) {
-			JSValue stack = JS_GetPropertyStr(context, exception, "stack");
-			if (!JS_IsException(stack)) {
-				stack_cstring = JS_ToCString(context, stack);
-				JS_FreeValue(context, stack);
-			}
-		}
-		if (cstring != NULL) {
-			const char *safe_stack_cstring = stack_cstring ? stack_cstring : "";
-			if (strstr(cstring, "stack overflow") != NULL) {
-				PyErr_Format(StackOverflow, "%s\n%s", cstring, safe_stack_cstring);
-			} else {
-				PyErr_Format(JSException, "%s\n%s", cstring, safe_stack_cstring);
-			}
-		} else {
-			// This has been observed to happen when different threads have used the same QuickJS
-			// runtime, but not at the same time.
-			// Could potentially be another problem though, since JS_ToCString may return NULL.
-			PyErr_Format(JSException,
-			             "(Failed obtaining QuickJS error string. Concurrency issue?)");
-		}
-		JS_FreeCString(context, cstring);
-		JS_FreeCString(context, stack_cstring);
-		JS_FreeValue(context, exception);
+		quickjs_exception_to_python(context);
 	} else if (tag == JS_TAG_FLOAT64) {
 		return_value = Py_BuildValue("d", JS_VALUE_GET_FLOAT64(value));
 	} else if (tag == JS_TAG_STRING) {
 		const char *cstring = JS_ToCString(context, value);
 		return_value = Py_BuildValue("s", cstring);
 		JS_FreeCString(context, cstring);
-	} else if (tag == JS_TAG_OBJECT || tag == JS_TAG_MODULE) {
+	} else if (tag == JS_TAG_OBJECT || tag == JS_TAG_MODULE || tag == JS_TAG_SYMBOL) {
 		// This is a Javascript object or function. We wrap it in a _quickjs.Object.
 		return_value = PyObject_CallObject((PyObject *)&Object, NULL);
 		ObjectData *object = (ObjectData *)return_value;
@@ -379,6 +396,24 @@ static PyObject *context_module(ContextData *self, PyObject *args) {
 	return context_eval_internal(self, args, JS_EVAL_TYPE_MODULE);
 }
 
+// _quickjs.Context.execute_pending_job
+//
+// If there are pending jobs, executes one and returns True. Else returns False.
+static PyObject *context_execute_pending_job(ContextData *self) {
+	prepare_call_js(self);
+	JSContext *ctx;
+	int ret = JS_ExecutePendingJob(self->runtime, &ctx);
+	end_call_js(self);
+	if (ret > 0) {
+		Py_RETURN_TRUE;
+	} else if (ret == 0) {
+		Py_RETURN_FALSE;
+	} else {
+		quickjs_exception_to_python(ctx);
+		return NULL;
+	}
+}
+
 // _quickjs.Context.parse_json
 //
 // Evaluates a Python string as JSON and returns the result as a Python object. Will
@@ -409,6 +444,31 @@ static PyObject *context_get(ContextData *self, PyObject *args) {
 	return quickjs_to_python(self, value);
 }
 
+// _quickjs.Context.set
+//
+// Sets a global variable to the JS context.
+static PyObject *context_set(ContextData *self, PyObject *args) {
+	const char *name;
+	PyObject *item;
+	if (!PyArg_ParseTuple(args, "sO", &name, &item)) {
+		return NULL;
+	}
+	JSValue global = JS_GetGlobalObject(self->context);
+	int ret = 0;
+	if (python_to_quickjs_possible(self, item)) {
+		ret = JS_SetPropertyStr(self->context, global, name, python_to_quickjs(self, item));
+		if (ret != 1) {
+			PyErr_SetString(PyExc_TypeError, "Failed setting the variable.");
+		}
+	}
+	JS_FreeValue(self->context, global);
+	if (ret == 1) {
+		Py_RETURN_NONE;
+	} else {
+		return NULL;
+	}
+}
+
 // _quickjs.Context.set_memory_limit
 //
 // Sets the memory limit of the context.
@@ -609,8 +669,10 @@ static PyMethodDef context_methods[] = {
      (PyCFunction)context_module,
      METH_VARARGS,
      "Evaluates a Javascript string as a module."},
+    {"execute_pending_job", (PyCFunction)context_execute_pending_job, METH_NOARGS, "Executes a pending job."},
     {"parse_json", (PyCFunction)context_parse_json, METH_VARARGS, "Parses a JSON string."},
     {"get", (PyCFunction)context_get, METH_VARARGS, "Gets a Javascript global variable."},
+    {"set", (PyCFunction)context_set, METH_VARARGS, "Sets a Javascript global variable."},
     {"set_memory_limit",
      (PyCFunction)context_set_memory_limit,
      METH_VARARGS,
